Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1511)

Unified Diff: content/public/common/content_switches.cc

Issue 10915117: Enable Media Source API by default. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix chrome_frame test Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/common/content_switches.h ('k') | content/renderer/render_thread_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/common/content_switches.cc
diff --git a/content/public/common/content_switches.cc b/content/public/common/content_switches.cc
index 6db3e8db0b5493363745db1fb21f0bcccef6cb64..80dc271a7513a1b3beb433571ca0cd454849ab98 100644
--- a/content/public/common/content_switches.cc
+++ b/content/public/common/content_switches.cc
@@ -304,8 +304,8 @@ const char kEnableGpuBenchmarking[] = "enable-gpu-benchmarking";
// builds.
const char kEnableLogging[] = "enable-logging";
-// Enables Media Source API on <audio>/<video> elements.
-const char kEnableMediaSource[] = "enable-media-source";
+// Disable Media Source API on <audio>/<video> elements.
+const char kDisableMediaSource[] = "disable-media-source";
// On Windows, converts the page to the currently-installed monitor profile.
// This does NOT enable color management for images. The source is still
« no previous file with comments | « content/public/common/content_switches.h ('k') | content/renderer/render_thread_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698